@@ -1,7 +1,8 @@
 package Kephra::Dialog;
-$VERSION = '0.18';
-
 use strict;
+use warnings;
+
+our $VERSION = '0.18';
 
 use Wx qw(:filedialog );    # :messagebox
 use Wx qw (wxDefaultPosition wxDefaultSize
